@@ -78,6 +78,13 @@ class _StructureLayer:
 		refcounters = {}
 		for table in tables:
 			rows = self._engine.execute("SELECT id FROM {}", [table])
+
+			# empty field tables are automatically deleted, so if we found
+			# one, it should be removed too
+			if len(rows) == 0:
+				self._engine.deleteTable(table)
+				continue
+
 			ids = [x[0] for x in rows]
 			field = Field.fromTableName(self._engine, table)
 			name_str = field.name_str
@@ -618,13 +625,13 @@ class _StructureLayer:
 				condition_str = ""
 
 			query_str = "FROM {} WHERE " + self._ID_COLUMN + "=? " + condition_str
-			tables = [field.table_name]
+			tables = [fields[0].table_name] # table names for all fields in group are the same
 			values = [id]
 
 			# get number of records to be deleted
 			# (unfortunately, some databases (like sqlite) do not return number of
 			# deleted rows as a result of DELETE query)
-			rows = self._engine.execute("SELECT COUNT(*) " + query_str, tables,values)
+			rows = self._engine.execute("SELECT COUNT(*) " + query_str, tables, values)
 			del_num = rows[0][0]
 
 			# if there are any, delete them
