@@ -244,17 +244,22 @@ stands for position in list. None is used in several special cases: to specify t
 `Connection.insert()`_ should perform insertion at the end of the list or as a mask for
 `Connection.delete()`_ and `Connection.read()`_.
 
+String elements must not contain uppercase symbols. This is done because each field name
+correspond to table name in underlying SQL engine, and some engines ignore case in table names.
+So, in order to avoid later search errors, uppercase symbols in field names are simply not allowed -
+`FormatError`_ is thrown.
+
 If path does not contain Nones, it is called *determined*.
 
 **Example**:
 
  >>> conn = brain.connect(None, None)
- >>> id1 = conn.create({'Tracks': [{'Name': 'track 1', 'Length': 240},
- ... {'Name': 'track 2', 'Length': 300}]})
- >>> print(conn.read(id1, ['Tracks', 0, 'Name']))
+ >>> id1 = conn.create({'tracks': [{'name': 'track 1', 'length': 240},
+ ... {'name': 'track 2', 'length': 300}]})
+ >>> print(conn.read(id1, ['tracks', 0, 'name']))
  track 1
- >>> print(conn.readByMask(id1, ['Tracks', None, 'Length']))
- {'Tracks': [{'Length': 240}, {'Length': 300}]}
+ >>> print(conn.readByMask(id1, ['tracks', None, 'length']))
+ {'tracks': [{'length': 240}, {'length': 300}]}
  >>> conn.close()
 
 .. _FacadeError:
@@ -345,7 +350,7 @@ The package is supplied with a set of functionality tests which I use for debugg
 They can be found in ``test`` subfolder of module main folder. Tests are executed using ``run.py``,
 which has the following parameters:
 
-``run.py <func|fuzz> [options]``
+``run.py <func|fuzz|doc|perf> [options]``
 
 ``func``:
   Functionality tests. They are based on Python's ``unittest`` module, with some minor extensions.
@@ -483,6 +488,7 @@ Currently the following connection methods are available:
  * `Connection.delete()`_
  * `Connection.deleteMany()`_
  * `Connection.dump()`_
+ * `Connection.getRemoveConflicts()`_
  * `Connection.insert()`_
  * `Connection.insertMany()`_
  * `Connection.modify()`_
@@ -681,11 +687,11 @@ other list elements are shifted correspondingly.
 
 * Deletion by mask
 
- >>> id1 = conn.create({'Tracks': [{'Name': 'track 1', 'Length': 240},
- ... {'Name': 'track 2', 'Length': 300}]})
- >>> conn.delete(id1, ['Tracks', None, 'Length'])
+ >>> id1 = conn.create({'tracks': [{'name': 'track 1', 'length': 240},
+ ... {'name': 'track 2', 'length': 300}]})
+ >>> conn.delete(id1, ['tracks', None, 'length'])
  >>> print(conn.read(id1))
- {'Tracks': [{'Name': 'track 1'}, {'Name': 'track 2'}]}
+ {'tracks': [{'name': 'track 1'}, {'name': 'track 2'}]}
  >>> conn.close()
 
 Connection.dump()
@@ -924,27 +930,27 @@ Read contents of given object.
 **Example**:
 
  >>> conn = brain.connect(None, None)
- >>> id1 = conn.create({'tracks': [{'Name': 'track 1', 'Length': 240}, {'Name': 'track 2', 'Length': 300}]})
+ >>> id1 = conn.create({'tracks': [{'name': 'track 1', 'length': 240}, {'name': 'track 2', 'length': 300}]})
 
 * Read the whole object
 
  >>> print(conn.read(id1))
- {'tracks': [{'Length': 240, 'Name': 'track 1'}, {'Length': 300, 'Name': 'track 2'}]}
+ {'tracks': [{'length': 240, 'name': 'track 1'}, {'length': 300, 'name': 'track 2'}]}
 
 * Read from given path
 
  >>> print(conn.read(id1, ['tracks', 0]))
- {'Length': 240, 'Name': 'track 1'}
+ {'length': 240, 'name': 'track 1'}
 
 * Read by mask
 
- >>> print(conn.readByMask(id1, ['tracks', None, 'Length']))
- {'tracks': [{'Length': 240}, {'Length': 300}]}
+ >>> print(conn.readByMask(id1, ['tracks', None, 'length']))
+ {'tracks': [{'length': 240}, {'length': 300}]}
 
 * Read from path, filter by mask. Note that mask is relative.
 
- >>> print(conn.read(id1, ['tracks'], [[None, 'Length']]))
- [{'Length': 240}, {'Length': 300}]
+ >>> print(conn.read(id1, ['tracks'], [[None, 'length']]))
+ [{'length': 240}, {'length': 300}]
  >>> conn.close()
 
 Connection.repair()
