@@ -6,11 +6,12 @@ import sys
 import doc
 import func
 import fuzz
+import perf
 
 # Parser settings
 
 parser = optparse.OptionParser(usage = "run.py <mode> [options]\n" +
-	"Modes: func, fuzz, doc")
+	"Modes: func, fuzz, doc, perf")
 
 parser.add_option("--ae", "--all-engines", action="store_true",
 	dest="all_engines", help="[func] run tests using all available DB engines")
@@ -35,7 +36,7 @@ if len(sys.argv) == 1:
 	parser.error("Error: mode should be specified")
 
 # FIXME: find a way to do it using OptionParser
-modes = ['func', 'fuzz', 'doc']
+modes = ['func', 'fuzz', 'doc', 'perf']
 mode = sys.argv[1]
 args = sys.argv[2:]
 
@@ -54,3 +55,5 @@ elif mode == 'fuzz':
 		seed=opts.seed, verbosity=opts.verbosity)
 elif mode == 'doc':
 	doc.runDocTest(verbosity=opts.verbosity)
+elif mode == 'perf':
+	perf.runPerformanceTests(verbosity=opts.verbosity)
